/**
 * Copyright (c) 2013 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.jmx.api.api;

import java.util.List;
import java.util.Map;

import org.ow2.petals.jmx.api.api.exception.EndpointRegistryServiceErrorException;
import org.ow2.petals.jmx.api.api.exception.PetalsAdminServiceErrorException;

/**
 * Interface of the JMX Endpoint service.
 * 
 * @author Christophe DENEUX - Linagora
 */
public interface EndpointRegistryClient {

    /**
     * Name of the associated MBean
     */
    public static final String ENDPOINT_REGISTRY_MBEAN_NAME = "EndpointRegistry";

    /**
     * Get all the internal Endpoints
     * 
     * @return a list of all internal enpoints. See {@link ReportKeyNames } for
     *         map constants.
     * @throws EndpointRegistryServiceErrorException
     */
    public List<Map<String, Object>> getAllInternalEndpoints()
            throws EndpointRegistryServiceErrorException;

    /**
     * Get all the external Endpoints
     * 
     * @return a list of all external enpoints. See {@link ReportKeyNames } for
     *         map constants.
     * @throws EndpointRegistryServiceErrorException
     */
    public List<Map<String, Object>> getAllExternalEndpoints()
            throws EndpointRegistryServiceErrorException;

    /**
     * Get all the Endpoints
     * 
     * @return a list of all enpoints. See {@link ReportKeyNames } for map
     *         constants.
     * @throws EndpointRegistryServiceErrorException
     */
    public List<Map<String, Object>> getAllEndpoints() throws EndpointRegistryServiceErrorException;

    /**
     * Get the description for a given service and endpoint
     * 
     * @throws EndpointRegistryServiceErrorException
     */
    public String getDescription(String serviceName, String endpointName)
            throws EndpointRegistryServiceErrorException;
    
    /**
     * Synchronize all registry members
     * 
     * @throws PetalsAdminServiceErrorException
     */
    public void synchronizeRegistry() throws PetalsAdminServiceErrorException;
}
